{% extends "apps/base.html" %}
{% load staticfiles %}

{% block extra_css %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static "css/pages/app-log.css" %}" />
{% endblock %}

{% block navbar %}
    {% include "apps/navbar.html" with active="log" %}
{% endblock %}

{% block app-content %}
<div class="container-fluid">
	<div class="row">
		<div class="col-md-12">
            <div id="logs"></div>
		</div>
	</div>
</div>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/oboe-browser.min.js" %}"></script>
<script src="{% static "js/log.js" %}"></script>
{% endblock %}
