.metrics-container div {
    margin: 2px;
    display: inline-block;
}

.metrics-options {
    display: block;
}

.metrics-options div {
    display: inline-block;
    padding: 10px;
}

.metrics-options label {
    padding-right: 10px;
    padding-left: 5px;
}

.metrics .graph-container, .metrics-container .graph-container {
    border: #777 1px solid;
    display: inline-block;
}

.graph-container h2 {
    font-size: 16px;
    margin: 0 38px;
}

.graph-container .graph {
    min-width: 285px;
    width: 100%;
    min-height: 205px;
    height: 95%;
}

.graphs-medium > .graph-container {
    width: 50%;
}

.graphs-large > .graph-container {
    width: 100%;
    height: 300px;
}

.metrics-loader {
  font-size: 3px;
  text-indent: -9999em;
  width: 5em;
  height: 5em;
  border-radius: 50%;
  background: #666;
  background: -moz-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -webkit-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -o-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -ms-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: linear-gradient(to right, #666 10%, rgba(255, 255, 255, 0) 42%);
  position: relative;
  -webkit-animation: load3 1.4s infinite linear;
  animation: load3 1.4s infinite linear;
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.metrics-loader:before {
  width: 50%;
  height: 50%;
  background: #666;
  border-radius: 100% 0 0 0;
  position: absolute;
  top: 0;
  left: 0;
  content: '';
}
.metrics-loader:after {
  background: #fff;
  width: 75%;
  height: 75%;
  border-radius: 50%;
  content: '';
  margin: auto;
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
}
@-webkit-keyframes load3 {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes load3 {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
